Bem vindo a PySIGEP!
====================

Interface python para uso dos serviços fornecidos pelo SIGEPWeb dos Correios.

O SIGEP WEB é um sistema com o propósito de preparar e gerenciar
as postagens de Clientes dos Correios. Seus principais atributos técnicos são:
facilidade e rapidez na preparação das postagens e gestão das informações sobre os objetos postados.

Features
--------

-  Verificar *status* de um Cartão de Postagem
-  Obter dados do endereço a partir de seu respectivo CEP.
-  Verificar disponibilidade de um dado serviço.
-  Gerar etiquetas para postagem de mercadoria.

.. toctree::
    :maxdepth: 2
    :hidden:
    :glob:

    installation
    usage
    contributing
    authors
    history
    modules

Encontrou algum erro? Tem alguma sugestão para melhorar a PySIGEP? Deixe-me saber.
Contribuições são muito bem vindas!